.. probinet documentation master file.

.. include:: ../../README.md
   :parser: myst_parser.sphinx_

References
----------

.. bibliography:: references.bib

Thank you for choosing ProbINet. We hope you enjoy using it!

.. toctree::
   :maxdepth: 1
   :caption: Contents

   api

.. toctree::
    :maxdepth: 1
    :caption: First Steps

    Inputs and Outputs <start.rst>

.. toctree::
   :maxdepth: 1
   :caption: Tutorials

   A Beginner's Guide To The MTCOV Algorithm In The Probinet Package <tutorials/MTCOV.ipynb>
   Generation Of Synthetic Networks Using The CRep Algorithm <tutorials/CRep.ipynb>
   Analysis Of A Real-World Dataset Using The JointCRep Algorithm <tutorials/JointCRep.ipynb>
   Decoding Temporal Relationships With DynCRep <tutorials/DynCRep.ipynb>
   Cross-Validation And Anomaly Detection With The ACD Algorithm <tutorials/ACD.ipynb>
   Analyzing Network Data With Unknown Community Structure <tutorials/Unknown_structure.ipynb>

.. toctree::
    :maxdepth: 1
    :caption: Contributing

    How To Contribute <contributing.rst>

.. toctree::
    :maxdepth: 1
    :caption: References

    Bibliography <references.rst>

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
